package com.fs.live.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.live.domain.LiveQuestion;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 问答Mapper接口
 *
 * @author fs
 * @date 2025-01-17
 */
public interface LiveQuestionMapper extends BaseMapper<LiveQuestion>
{
    /**
     * 查询问答
     *
     * @param questionId 问答主键
     * @return 问答
     */
    public LiveQuestion selectLiveQuestionByQuestionId(Long questionId);

    /**
     * 查询企业问答
     * @param questionId        问答ID
     * @param companyId         企业ID
     * @param companyUserId     企业用户ID
     * @return LiveQuestion
     */
    LiveQuestion selectLiveQuestionByQuestionIdAndCompanyIdAndCompanyUserId(@Param("questionId") Long questionId, @Param("companyId") Long companyId, @Param("companyUserId") Long companyUserId);

    /**
     * 查询问答列表
     *
     * @param liveQuestion 问答
     * @return 问答集合
     */
    public List<LiveQuestion> selectLiveQuestionList(LiveQuestion liveQuestion);

    /**
     * 新增问答
     *
     * @param liveQuestion 问答
     * @return 结果
     */
    public int insertLiveQuestion(LiveQuestion liveQuestion);

    /**
     * 修改问答
     *
     * @param liveQuestion 问答
     * @return 结果
     */
    public int updateLiveQuestion(LiveQuestion liveQuestion);

    /**
     * 删除问答
     *
     * @param questionId 问答主键
     * @return 结果
     */
    public int deleteLiveQuestionByQuestionId(Long questionId);

    /**
     * 批量删除问答
     *
     * @param questionIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLiveQuestionByQuestionIds(Long[] questionIds);
}
