package com.fs.live.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.live.domain.LiveStudentData;
import com.fs.live.param.LiveStudentDataQueryParam;

import java.util.List;

/**
 * 直播间学员数据Service接口
 *
 * @author fs
 * @date 2025-03-11
 */
public interface ILiveStudentDataService extends IService<LiveStudentData>{
    /**
     * 查询直播间学员数据
     *
     * @param liveId 直播间学员数据主键
     * @return 直播间学员数据
     */
    LiveStudentData selectLiveStudentDataByLiveId(Long liveId);

    /**
     * 查询直播间学员数据列表
     *
     * @param liveStudentData 直播间学员数据
     * @return 直播间学员数据集合
     */
    List<LiveStudentData> selectLiveStudentDataList(LiveStudentData liveStudentData);

    /**
     * 新增直播间学员数据
     *
     * @param liveStudentData 直播间学员数据
     * @return 结果
     */
    int insertLiveStudentData(LiveStudentData liveStudentData);

    /**
     * 修改直播间学员数据
     *
     * @param liveStudentData 直播间学员数据
     * @return 结果
     */
    int updateLiveStudentData(LiveStudentData liveStudentData);

    /**
     * 批量删除直播间学员数据
     *
     * @param liveIds 需要删除的直播间学员数据主键集合
     * @return 结果
     */
    int deleteLiveStudentDataByLiveIds(Long[] liveIds);

    /**
     * 删除直播间学员数据信息
     *
     * @param liveId 直播间学员数据主键
     * @return 结果
     */
    int deleteLiveStudentDataByLiveId(Long liveId);

    /**
     * 查询直播数据统计页直播间学员模块数据
     * @param param
     * @return
     */
    List<LiveStudentData> queryStudentData(LiveStudentDataQueryParam param);
}
